AnimatedDropdownSearch class

Inheritance

Constructors

AnimatedDropdownSearch({Key? key, required List<String> data, required dynamic onSelected(String val)?, String? hint, dynamic onSelectedMultiple(List<String> values)?, TextStyle? hintStyle, TextStyle? optionTextStyle, Color? selectedHighlightColor, bool? enableSearch, double? maxHeightForOptions, Color? scrollPercentageColorIndicator, InputBorder? border, int? minCharactersToHighlight, bool? shouldHighlightMatchedText, Color? matchedTextHighlightColor, bool? enableAdaptivePositioning, bool shouldAnimate = true, TextEditingController? searchController, FocusNode? searchFocusNode, Color? fillColor, bool filled = true, Alignment optionsAlignment = Alignment.topCenter, double? width, Color? overlayBackgroundColor, Color? cursorColor, double? cursorHeight, double? cursorWidth, Color? highlghtedTextColor, Color optionTileColor = Colors.white})
const
AnimatedDropdownSearch.multiple({Key? key, required List<String> data, required dynamic onSelectedMultiple(List<String> values)?, String? hint, dynamic onSelected(String val)?, TextStyle? hintStyle, TextStyle? optionTextStyle, Color? selectedHighlightColor, bool? enableSearch, double? maxHeightForOptions, Color? scrollPercentageColorIndicator, InputBorder? border, int? minCharactersToHighlight, bool? shouldHighlightMatchedText, Color? matchedTextHighlightColor, bool? enableAdaptivePositioning, bool shouldAnimate = true, TextEditingController? searchController, FocusNode? searchFocusNode, double? width, Color? fillColor, bool filled = true, Alignment optionsAlignment = Alignment.topCenter, bool showSelectedOptions = true, Color? overlayBackgroundColor, Color? cursorColor, double? cursorHeight, double? cursorWidth, Color? highlghtedTextColor, Color optionTileColor = Colors.white})
const

Properties

border InputBorder?
Input border for the search field.
final
canSelectMultiple bool
Boolean to enable/disable multiple selection.
final
cursorColor Color?
The color of the text cursor within the input field.
final
cursorHeight double?
The height of the text cursor.
final
cursorWidth double?
The width of the text cursor.
final
data List<String>
List of strings to display in the dropdown.
final
enableAdaptivePositioning bool?
Boolean to enable/disable adaptive positioning on the options based on the available space and maxheight (top/bottom)
final
enableSearch bool?
Boolean to enable/disable search functionality.
final
fillColor Color?
Fill color for the search field. Defaults to white.
final
filled bool
Determines whether the search field should be filled. Defaults to true.
final
hashCode int
The hash code for this object.
no setterinherited
highlghtedTextColor Color?
The color used to highlight matching search results in the options list.
final
hint String?
Placeholder text for the search field.
final
hintStyle TextStyle?
Style for the hint text.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
matchedTextHighlightColor Color?
Color for the matched text highlight.
final
maxHeightForOptions double?
Maximum height for the options dropdown.
final
minCharactersToHighlight int?
Minimum number of characters before highlighting matched text.
final
onSelected → dynamic Function(String val)?
Callback function when an item is selected.
final
onSelectedMultiple → dynamic Function(List<String> values)?
Callback function when an item is selected.
final
optionsAlignment Alignment
Alignment for the options list view. Defaults to Alignment.topCenter.
final
optionTextStyle TextStyle?
Style for the dropdown options.
final
optionTileColor Color
The background color of each option tile in the dropdown list.
final
overlayBackgroundColor Color?
The background color of the overlay that appears beneath the dropdown or options list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPercentageColorIndicator Color?
Color for the scroll percentage indicator.
final
searchController TextEditingController?
Controller for the search text field.
final
searchFocusNode FocusNode?
Focus node for the search text field.
final
selectedHighlightColor Color?
Color for the selected option highlight.
final
shouldAnimate bool
Enables/disables slide animation on dropdown options. Defaults to true.
final
shouldHighlightMatchedText bool?
Boolean to enable/disable highlighting matched text.
final
showSelectedOptions bool
Boolean to enable/disable highlighting matched text.
final
width double?
Maximum width for the options dropdown.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AnimatedDropdownSearch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited