enableAdaptivePositioning property
Boolean to enable/disable adaptive positioning on the options based on the available space and maxheight (top/bottom)
Implementation
final bool? enableAdaptivePositioning;
Boolean to enable/disable adaptive positioning on the options based on the available space and maxheight (top/bottom)
final bool? enableAdaptivePositioning;