highlghtedTextColor property
The color used to highlight matching search results in the options list.
Implementation
final Color? highlghtedTextColor;
The color used to highlight matching search results in the options list.
final Color? highlghtedTextColor;