overlayBackgroundColor property
The background color of the overlay that appears beneath the dropdown or options list.
Implementation
final Color? overlayBackgroundColor;
The background color of the overlay that appears beneath the dropdown or options list.
final Color? overlayBackgroundColor;